package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.GtgsBg;
import com.ruoyi.system.mapper.GtgsBgMapper;
import com.ruoyi.system.service.IGtgsBgService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 个体工商变更Service业务层处理
 * 
 * @author ruoyi
 * @date 2020-05-13
 */
@Service
public class GtgsBgServiceImpl implements IGtgsBgService
{
    @Autowired
    private GtgsBgMapper gtgsBgMapper;

    /**
     * 查询个体工商变更
     * 
     * @param id 个体工商变更ID
     * @return 个体工商变更
     */
    @Override
    public GtgsBg selectGtgsBgById(String id)
    {
        return gtgsBgMapper.selectGtgsBgById(id);
    }

    /**
     * 查询个体工商变更列表
     * 
     * @param gtgsBg 个体工商变更
     * @return 个体工商变更
     */
    @Override
    public List<GtgsBg> selectGtgsBgList(GtgsBg gtgsBg)
    {
        return gtgsBgMapper.selectGtgsBgList(gtgsBg);
    }

    /**
     * 新增个体工商变更
     * 
     * @param gtgsBg 个体工商变更
     * @return 结果
     */
    @Override
    public int insertGtgsBg(GtgsBg gtgsBg)
    {
        gtgsBg.setCreateTime(DateUtils.getNowDate());
        return gtgsBgMapper.insertGtgsBg(gtgsBg);
    }

    /**
     * 修改个体工商变更
     * 
     * @param gtgsBg 个体工商变更
     * @return 结果
     */
    @Override
    public int updateGtgsBg(GtgsBg gtgsBg)
    {
        gtgsBg.setUpdateTime(DateUtils.getNowDate());
        return gtgsBgMapper.updateGtgsBg(gtgsBg);
    }

    @Override
    public int changeGtgsFlagTg(GtgsBg gtgsBg) {
        return gtgsBgMapper.changeGtgsFlagTg(gtgsBg);
    }

    /**
     * 删除个体工商变更对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteGtgsBgByIds(String ids)
    {
        return gtgsBgMapper.deleteGtgsBgByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除个体工商变更信息
     * 
     * @param id 个体工商变更ID
     * @return 结果
     */
    public int deleteGtgsBgById(String id)
    {
        return gtgsBgMapper.deleteGtgsBgById(id);
    }


}
